/soc/2013/ankitkv/gobjectification: 70b4272d57f9: Fixed some doc...

Ankit Vani a at nevitus.org
Thu Oct 10 17:37:17 EDT 2013


Changeset: 70b4272d57f91b0ee91a6dd8c332c0e72344f43c
Author:	 Ankit Vani <a at nevitus.org>
Date:	 2013-10-11 03:07 +0530
Branch:	 soc.2013.gobjectification
URL: https://hg.pidgin.im/soc/2013/ankitkv/gobjectification/rev/70b4272d57f9

Description:

Fixed some documentation

diffstat:

 libpurple/signals.h |  8 ++++----
 libpurple/status.c  |  2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diffs (40 lines):

diff --git a/libpurple/status.c b/libpurple/status.c
--- a/libpurple/status.c
+++ b/libpurple/status.c
@@ -671,7 +671,7 @@ purple_status_set_active(PurpleStatus *s
 /*
  * This used to parse the va_list directly, but now it creates a GList
  * and passes it to purple_status_set_active_with_attrs_list().  That
- * function was created because accounts.c needs to pass a GList of
+ * function was created because account.c needs to pass a GList of
  * attributes to the status API.
  */
 void



More information about the Commits mailing list
diff --git a/libpurple/signals.h b/libpurple/signals.h
--- a/libpurple/signals.h
+++ b/libpurple/signals.h
@@ -70,7 +70,7 @@ G_BEGIN_DECLS
  * @param marshal    The marshal function.
  * @param ret_type   The return type, or G_TYPE_NONE for no return type.
  * @param num_values The number of values to be passed to the callbacks.
- * @param ...        The values to pass to the callbacks.
+ * @param ...        The types of the parameters for the callbacks.
  *
  * @return The signal ID local to that instance, or 0 if the signal
  *         couldn't be registered.
@@ -100,12 +100,12 @@ void purple_signals_unregister_by_instan
  * @param instance    The instance the signal is registered to.
  * @param signal      The signal.
  * @param ret_type    The return type.
  * @param num_values  The returned number of values.
  * @param value_types The returned list of values.
  */
 void purple_signal_get_types(void *instance, const char *signal,
 							GType *ret_type, int *num_values,
-							GType **value_types);
+							GType **param_types);
 
 /**
  * Connects a signal handler to a signal for a particular object.
@@ -100,12 +100,12 @@ void purple_signals_unregister_by_instan
  * @param signal      The signal.
  * @param ret_type    The return type.
- * @param num_values  The returned number of values.
- * @param value_types The returned list of values.
+ * @param num_values  The returned number of parameters.
+ * @param param_types The returned list of parameter types.
  */
 void purple_signal_get_types(void *instance, const char *signal,